@@ -13,7 +13,7 @@ class Logger(object):
     This class represents the Logger level and the file path.
     """
 
-    def __init__(self, level, file_path):
+    def __init__(self, level, file_path=None):
         self.__level = level
         self.__file_path = file_path
 
@@ -38,7 +38,7 @@ class Logger(object):
         return self.__file_path
 
     @staticmethod
-    def get_instance(level, file_path):
+    def get_instance(level, file_path=None):
 
         """
         Creates an Logger class instance with the specified log level and file path.
@@ -74,12 +74,18 @@ class SDKLogger(object):
     def __init__(self, logger_instance):
 
         logger = logging.getLogger('SDKLogger')
-        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(module)s - %(filename)s - %(funcName)s - %(lineno)d  - %(message)s')
-        logger.setLevel(logger_instance.get_level().name)
-        file_handler = logging.FileHandler(logger_instance.get_file_path())
-        file_handler.setLevel(logger_instance.get_level().name)
-        file_handler.setFormatter(formatter)
-        logger.addHandler(file_handler)
+        logger_level = logger_instance.get_level()
+        logger_file_path = logger_instance.get_file_path()
+        if logger_level is not None and logger_level != logging.NOTSET and logger_file_path is not None and logger_file_path != "":
+            file_handler = logging.FileHandler(logger_file_path)
+            formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(module)s - %(filename)s - %(funcName)s - %(lineno)d  - %(message)s')
+            file_handler.setLevel(logger_level.name)
+            file_handler.setFormatter(formatter)
+            logger.addHandler(file_handler)
+        if logger_level is not None and Constants.LOGGER_LEVELS.__contains__(logger_level.name):
+            logger.setLevel(logger_level.name)
+
+
 
     @staticmethod
     def initialize(logger_instance):
