@@ -50,7 +50,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -59,7 +59,7 @@ class RecordOperations(object):
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		handler_instance.set_param(param_instance)
 		handler_instance.set_header(header_instance)
-		Utility.get_fields(module_api_name, handler_instance)
+		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
@@ -67,7 +67,7 @@ class RecordOperations(object):
 			from .response_handler import ResponseHandler
 		return handler_instance.api_call(ResponseHandler.__module__, 'application/json')
 
-	def update_record(self, id, module_api_name, request):
+	def update_record(self, id, module_api_name, request, header_instance=None):
 		"""
 		The method to update record
 
@@ -75,6 +75,7 @@ class RecordOperations(object):
 			id (int) : An int representing the id
 			module_api_name (string) : A string representing the module_api_name
 			request (BodyWrapper) : An instance of BodyWrapper
+			header_instance (HeaderMap) : An instance of HeaderMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -97,9 +98,12 @@ class RecordOperations(object):
 		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -108,7 +112,8 @@ class RecordOperations(object):
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
-		Utility.get_fields(module_api_name, handler_instance)
+		handler_instance.set_header(header_instance)
+		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
@@ -116,7 +121,7 @@ class RecordOperations(object):
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def delete_record(self, id, module_api_name, param_instance=None):
+	def delete_record(self, id, module_api_name, param_instance=None, header_instance=None):
 		"""
 		The method to delete record
 
@@ -124,6 +129,7 @@ class RecordOperations(object):
 			id (int) : An int representing the id
 			module_api_name (string) : A string representing the module_api_name
 			param_instance (ParameterMap) : An instance of ParameterMap
+			header_instance (HeaderMap) : An instance of HeaderMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -141,9 +147,12 @@ class RecordOperations(object):
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -151,6 +160,7 @@ class RecordOperations(object):
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
 		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
 		handler_instance.set_param(param_instance)
+		handler_instance.set_header(header_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
@@ -184,14 +194,14 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		handler_instance.set_param(param_instance)
 		handler_instance.set_header(header_instance)
-		Utility.get_fields(module_api_name, handler_instance)
+		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
@@ -199,13 +209,14 @@ class RecordOperations(object):
 			from .response_handler import ResponseHandler
 		return handler_instance.api_call(ResponseHandler.__module__, 'application/json')
 
-	def create_records(self, module_api_name, request):
+	def create_records(self, module_api_name, request, header_instance=None):
 		"""
 		The method to create records
 
 		Parameters:
 			module_api_name (string) : A string representing the module_api_name
 			request (BodyWrapper) : An instance of BodyWrapper
+			header_instance (HeaderMap) : An instance of HeaderMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -225,9 +236,12 @@ class RecordOperations(object):
 		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
@@ -235,7 +249,8 @@ class RecordOperations(object):
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
 		handler_instance.set_mandatory_checker(True)
-		Utility.get_fields(module_api_name, handler_instance)
+		handler_instance.set_header(header_instance)
+		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
@@ -243,13 +258,14 @@ class RecordOperations(object):
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def update_records(self, module_api_name, request):
+	def update_records(self, module_api_name, request, header_instance=None):
 		"""
 		The method to update records
 
 		Parameters:
 			module_api_name (string) : A string representing the module_api_name
 			request (BodyWrapper) : An instance of BodyWrapper
+			header_instance (HeaderMap) : An instance of HeaderMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -269,9 +285,12 @@ class RecordOperations(object):
 		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
@@ -279,7 +298,8 @@ class RecordOperations(object):
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
 		handler_instance.set_mandatory_checker(True)
-		Utility.get_fields(module_api_name, handler_instance)
+		handler_instance.set_header(header_instance)
+		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
@@ -287,13 +307,14 @@ class RecordOperations(object):
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def delete_records(self, module_api_name, param_instance=None):
+	def delete_records(self, module_api_name, param_instance=None, header_instance=None):
 		"""
 		The method to delete records
 
 		Parameters:
 			module_api_name (string) : A string representing the module_api_name
 			param_instance (ParameterMap) : An instance of ParameterMap
+			header_instance (HeaderMap) : An instance of HeaderMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -308,27 +329,32 @@ class RecordOperations(object):
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
 		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
 		handler_instance.set_param(param_instance)
+		handler_instance.set_header(header_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def upsert_records(self, module_api_name, request):
+	def upsert_records(self, module_api_name, request, header_instance=None):
 		"""
 		The method to upsert records
 
 		Parameters:
 			module_api_name (string) : A string representing the module_api_name
 			request (BodyWrapper) : An instance of BodyWrapper
+			header_instance (HeaderMap) : An instance of HeaderMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -348,9 +374,12 @@ class RecordOperations(object):
 		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/upsert'
 		handler_instance.set_api_path(api_path)
@@ -358,7 +387,8 @@ class RecordOperations(object):
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_ACTION)
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
-		Utility.get_fields(module_api_name, handler_instance)
+		handler_instance.set_header(header_instance)
+		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
@@ -393,7 +423,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/deleted'
 		handler_instance.set_api_path(api_path)
@@ -407,13 +437,14 @@ class RecordOperations(object):
 			from .deleted_records_handler import DeletedRecordsHandler
 		return handler_instance.api_call(DeletedRecordsHandler.__module__, 'application/json')
 
-	def search_records(self, module_api_name, param_instance=None):
+	def search_records(self, module_api_name, param_instance=None, header_instance=None):
 		"""
 		The method to search records
 
 		Parameters:
 			module_api_name (string) : A string representing the module_api_name
 			param_instance (ParameterMap) : An instance of ParameterMap
+			header_instance (HeaderMap) : An instance of HeaderMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -428,16 +459,20 @@ class RecordOperations(object):
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/search'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		handler_instance.set_param(param_instance)
-		Utility.get_fields(module_api_name, handler_instance)
+		handler_instance.set_header(header_instance)
+		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
@@ -473,7 +508,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/Leads/'
+		api_path = api_path + '/crm/v2/Leads/'
 		api_path = api_path + str(id)
 		api_path = api_path + '/actions/convert'
 		handler_instance.set_api_path(api_path)
@@ -482,7 +517,7 @@ class RecordOperations(object):
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
 		handler_instance.set_mandatory_checker(True)
-		Utility.get_fields("Deals", handler_instance)
+		Utility.get_fields("Deals")
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.convert_action_handler import ConvertActionHandler
 		except Exception:
@@ -512,7 +547,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -558,7 +593,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -599,7 +634,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -641,7 +676,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/actions/mass_update'
 		handler_instance.set_api_path(api_path)
@@ -650,7 +685,7 @@ class RecordOperations(object):
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
 		handler_instance.set_mandatory_checker(True)
-		Utility.get_fields(module_api_name, handler_instance)
+		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.mass_update_action_handler import MassUpdateActionHandler
@@ -681,7 +716,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/actions/mass_update'
 		handler_instance.set_api_path(api_path)
@@ -694,203 +729,15 @@ class RecordOperations(object):
 			from .mass_update_response_handler import MassUpdateResponseHandler
 		return handler_instance.api_call(MassUpdateResponseHandler.__module__, 'application/json')
 
-	def assign_territories_to_multiple_records(self, module_api_name, request):
+	def get_record_using_external_id(self, external_field_value, module_api_name, param_instance=None, header_instance=None):
 		"""
-		The method to assign territories to multiple records
-
-		Parameters:
-			module_api_name (string) : A string representing the module_api_name
-			request (BodyWrapper) : An instance of BodyWrapper
-
-		Returns:
-			APIResponse: An instance of APIResponse
-
-		Raises:
-			SDKException
-		"""
-
-		try:
-			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
-		except Exception:
-			from .body_wrapper import BodyWrapper
-
-		if not isinstance(module_api_name, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
-		
-		if request is not None and not isinstance(request, BodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
-		
-		handler_instance = CommonAPIHandler()
-		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
-		api_path = api_path + str(module_api_name)
-		api_path = api_path + '/actions/assign_territories'
-		handler_instance.set_api_path(api_path)
-		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
-		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
-		handler_instance.set_content_type('application/json')
-		handler_instance.set_request(request)
-		handler_instance.set_mandatory_checker(True)
-		Utility.get_fields(module_api_name, handler_instance)
-		handler_instance.set_module_api_name(module_api_name)
-		try:
-			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
-		except Exception:
-			from .action_handler import ActionHandler
-		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
-
-	def assign_territory_to_record(self, module_api_name, id, request):
-		"""
-		The method to assign territory to record
-
-		Parameters:
-			module_api_name (string) : A string representing the module_api_name
-			id (int) : An int representing the id
-			request (BodyWrapper) : An instance of BodyWrapper
-
-		Returns:
-			APIResponse: An instance of APIResponse
-
-		Raises:
-			SDKException
-		"""
-
-		try:
-			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
-		except Exception:
-			from .body_wrapper import BodyWrapper
-
-		if not isinstance(module_api_name, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
-		
-		if not isinstance(id, int):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
-		
-		if request is not None and not isinstance(request, BodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
-		
-		handler_instance = CommonAPIHandler()
-		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
-		api_path = api_path + str(module_api_name)
-		api_path = api_path + '/'
-		api_path = api_path + str(id)
-		api_path = api_path + '/actions/assign_territories'
-		handler_instance.set_api_path(api_path)
-		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
-		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
-		handler_instance.set_content_type('application/json')
-		handler_instance.set_request(request)
-		Utility.get_fields(module_api_name, handler_instance)
-		handler_instance.set_module_api_name(module_api_name)
-		try:
-			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
-		except Exception:
-			from .action_handler import ActionHandler
-		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
-
-	def remove_territories_from_multiple_records(self, module_api_name, request):
-		"""
-		The method to remove territories from multiple records
-
-		Parameters:
-			module_api_name (string) : A string representing the module_api_name
-			request (BodyWrapper) : An instance of BodyWrapper
-
-		Returns:
-			APIResponse: An instance of APIResponse
-
-		Raises:
-			SDKException
-		"""
-
-		try:
-			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
-		except Exception:
-			from .body_wrapper import BodyWrapper
-
-		if not isinstance(module_api_name, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
-		
-		if request is not None and not isinstance(request, BodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
-		
-		handler_instance = CommonAPIHandler()
-		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
-		api_path = api_path + str(module_api_name)
-		api_path = api_path + '/actions/remove_territories'
-		handler_instance.set_api_path(api_path)
-		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
-		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
-		handler_instance.set_content_type('application/json')
-		handler_instance.set_request(request)
-		handler_instance.set_mandatory_checker(True)
-		Utility.get_fields(module_api_name, handler_instance)
-		handler_instance.set_module_api_name(module_api_name)
-		try:
-			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
-		except Exception:
-			from .action_handler import ActionHandler
-		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
-
-	def remove_territories_from_record(self, module_api_name, id, request):
-		"""
-		The method to remove territories from record
-
-		Parameters:
-			module_api_name (string) : A string representing the module_api_name
-			id (int) : An int representing the id
-			request (BodyWrapper) : An instance of BodyWrapper
-
-		Returns:
-			APIResponse: An instance of APIResponse
-
-		Raises:
-			SDKException
-		"""
-
-		try:
-			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
-		except Exception:
-			from .body_wrapper import BodyWrapper
-
-		if not isinstance(module_api_name, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
-		
-		if not isinstance(id, int):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
-		
-		if request is not None and not isinstance(request, BodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
-		
-		handler_instance = CommonAPIHandler()
-		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
-		api_path = api_path + str(module_api_name)
-		api_path = api_path + '/'
-		api_path = api_path + str(id)
-		api_path = api_path + '/actions/remove_territories'
-		handler_instance.set_api_path(api_path)
-		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
-		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
-		handler_instance.set_content_type('application/json')
-		handler_instance.set_request(request)
-		Utility.get_fields(module_api_name, handler_instance)
-		handler_instance.set_module_api_name(module_api_name)
-		try:
-			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
-		except Exception:
-			from .action_handler import ActionHandler
-		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
-
-	def record_count(self, module_api_name, param_instance=None):
-		"""
-		The method to record count
+		The method to get record using external id
 
 		Parameters:
+			external_field_value (string) : A string representing the external_field_value
 			module_api_name (string) : A string representing the module_api_name
 			param_instance (ParameterMap) : An instance of ParameterMap
+			header_instance (HeaderMap) : An instance of HeaderMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -899,26 +746,136 @@ class RecordOperations(object):
 			SDKException
 		"""
 
+		if not isinstance(external_field_value, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: external_field_value EXPECTED TYPE: str', None, None)
+		
 		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + '/crm/v2/'
 		api_path = api_path + str(module_api_name)
-		api_path = api_path + '/actions/count'
+		api_path = api_path + '/'
+		api_path = api_path + str(external_field_value)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		handler_instance.set_param(param_instance)
+		handler_instance.set_header(header_instance)
+		Utility.get_fields(module_api_name)
+		handler_instance.set_module_api_name(module_api_name)
 		try:
-			from zcrmsdk.src.com.zoho.crm.api.record.count_handler import CountHandler
+			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
 		except Exception:
-			from .count_handler import CountHandler
-		return handler_instance.api_call(CountHandler.__module__, 'application/json')
+			from .response_handler import ResponseHandler
+		return handler_instance.api_call(ResponseHandler.__module__, 'application/json')
+
+	def update_record_using_external_id(self, external_field_value, module_api_name, request, header_instance=None):
+		"""
+		The method to update record using external id
+
+		Parameters:
+			external_field_value (string) : A string representing the external_field_value
+			module_api_name (string) : A string representing the module_api_name
+			request (BodyWrapper) : An instance of BodyWrapper
+			header_instance (HeaderMap) : An instance of HeaderMap
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
+		except Exception:
+			from .body_wrapper import BodyWrapper
+
+		if not isinstance(external_field_value, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: external_field_value EXPECTED TYPE: str', None, None)
+		
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/'
+		api_path = api_path + str(external_field_value)
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_header(header_instance)
+		Utility.get_fields(module_api_name)
+		handler_instance.set_module_api_name(module_api_name)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
+		except Exception:
+			from .action_handler import ActionHandler
+		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
+
+	def delete_record_using_external_id(self, external_field_value, module_api_name, param_instance=None, header_instance=None):
+		"""
+		The method to delete record using external id
+
+		Parameters:
+			external_field_value (string) : A string representing the external_field_value
+			module_api_name (string) : A string representing the module_api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
+			header_instance (HeaderMap) : An instance of HeaderMap
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		if not isinstance(external_field_value, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: external_field_value EXPECTED TYPE: str', None, None)
+		
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/'
+		api_path = api_path + str(external_field_value)
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_param(param_instance)
+		handler_instance.set_header(header_instance)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
+		except Exception:
+			from .action_handler import ActionHandler
+		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
 
 class GetRecordParam(object):
@@ -935,12 +892,21 @@ class GetRecordParam(object):
 
 class GetRecordHeader(object):
 	if_modified_since = Header('If-Modified-Since', 'com.zoho.crm.api.Record.GetRecordHeader')
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.GetRecordHeader')
+
+
+class UpdateRecordHeader(object):
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.UpdateRecordHeader')
 
 
 class DeleteRecordParam(object):
 	wf_trigger = Param('wf_trigger', 'com.zoho.crm.api.Record.DeleteRecordParam')
 
 
+class DeleteRecordHeader(object):
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.DeleteRecordHeader')
+
+
 class GetRecordsParam(object):
 	approved = Param('approved', 'com.zoho.crm.api.Record.GetRecordsParam')
 	converted = Param('converted', 'com.zoho.crm.api.Record.GetRecordsParam')
@@ -960,6 +926,15 @@ class GetRecordsParam(object):
 
 class GetRecordsHeader(object):
 	if_modified_since = Header('If-Modified-Since', 'com.zoho.crm.api.Record.GetRecordsHeader')
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.GetRecordsHeader')
+
+
+class CreateRecordsHeader(object):
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.CreateRecordsHeader')
+
+
+class UpdateRecordsHeader(object):
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.UpdateRecordsHeader')
 
 
 class DeleteRecordsParam(object):
@@ -967,6 +942,14 @@ class DeleteRecordsParam(object):
 	wf_trigger = Param('wf_trigger', 'com.zoho.crm.api.Record.DeleteRecordsParam')
 
 
+class DeleteRecordsHeader(object):
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.DeleteRecordsHeader')
+
+
+class UpsertRecordsHeader(object):
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.UpsertRecordsHeader')
+
+
 class GetDeletedRecordsParam(object):
 	type = Param('type', 'com.zoho.crm.api.Record.GetDeletedRecordsParam')
 	page = Param('page', 'com.zoho.crm.api.Record.GetDeletedRecordsParam')
@@ -986,14 +969,41 @@ class SearchRecordsParam(object):
 	approved = Param('approved', 'com.zoho.crm.api.Record.SearchRecordsParam')
 	page = Param('page', 'com.zoho.crm.api.Record.SearchRecordsParam')
 	per_page = Param('per_page', 'com.zoho.crm.api.Record.SearchRecordsParam')
+	fields = Param('fields', 'com.zoho.crm.api.Record.SearchRecordsParam')
+
+
+class SearchRecordsHeader(object):
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.SearchRecordsHeader')
 
 
 class GetMassUpdateStatusParam(object):
 	job_id = Param('job_id', 'com.zoho.crm.api.Record.GetMassUpdateStatusParam')
 
 
-class RecordCountParam(object):
-	criteria = Param('criteria', 'com.zoho.crm.api.Record.RecordCountParam')
-	email = Param('email', 'com.zoho.crm.api.Record.RecordCountParam')
-	phone = Param('phone', 'com.zoho.crm.api.Record.RecordCountParam')
-	word = Param('word', 'com.zoho.crm.api.Record.RecordCountParam')
+class GetRecordUsingExternalIDParam(object):
+	approved = Param('approved', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	converted = Param('converted', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	cvid = Param('cvid', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	uid = Param('uid', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	fields = Param('fields', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	startdatetime = Param('startDateTime', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	enddatetime = Param('endDateTime', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	territory_id = Param('territory_id', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	include_child = Param('include_child', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+
+
+class GetRecordUsingExternalIDHeader(object):
+	if_modified_since = Header('If-Modified-Since', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDHeader')
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDHeader')
+
+
+class UpdateRecordUsingExternalIDHeader(object):
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.UpdateRecordUsingExternalIDHeader')
+
+
+class DeleteRecordUsingExternalIDParam(object):
+	wf_trigger = Param('wf_trigger', 'com.zoho.crm.api.Record.DeleteRecordUsingExternalIDParam')
+
+
+class DeleteRecordUsingExternalIDHeader(object):
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.DeleteRecordUsingExternalIDHeader')
