@@ -31,7 +31,7 @@ class Constants(object):
 
     PHOTO = "photo"
 
-    API_VERSION = "v2.1"
+    API_VERSION = "v2"
 
     CRM = "crm"
 
@@ -44,9 +44,7 @@ class Constants(object):
         "INFO": "INFO",
         "DEBUG": "DEBUG",
         "NOTSET": "NOTSET"
-    }
-    INVENTORY_MODULES_ITEMS = ["invoiced_items", "quoted_items","purchase_items","ordered_items"]
-      
+    }      
 
     DEFAULT_MODULENAME_VS_APINAME = {
 
@@ -170,13 +168,15 @@ class Constants(object):
 
     OBJECT_KEY = "object"
 
-    PHOTO_SUPPORTED_MODULES = ["Leads", "Contacts", "Accounts", "Products", "Vendors", "Deals", "Cases", "Solutions"]
+    PHOTO_SUPPORTED_MODULES = ["leads", "contacts", "accounts", "products", "vendors", "deals", "cases", "solutions"]
 
     GIVEN_LENGTH = "given-length"
 
     ZOHO_SDK = "X-ZOHO-SDK"
 
-    SDK_VERSION = "4.0.0"
+    SDK_VERSION = "2.0.0"
+
+    ZOHO_API_VERSION = "2.0"
 
     CONTENT_DISPOSITION = "Content-Disposition"
 
@@ -318,20 +318,8 @@ class Constants(object):
 
     LINE_TAX_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.LineTax"
 
-    TAX_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.Tax"
-
-    PRODUCTS = "Products"
-
-    TAX = "TAX"
-
-    TERRITORY = "Territory"
-
     REMINDER_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.Reminder"
 
-    TERRITORY_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.Territory"
-
-    IMAGEUPLOAD_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.ImageUpload"
-
     ATTACHMENTS_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.attachments.Attachment"
 
     RECURRING_ACTIVITY_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.RecurringActivity"
@@ -418,10 +406,6 @@ class Constants(object):
 
     DATETIME_NAMESPACE = 'DateTime'
 
-    DISCOUNT = "DISCOUNT"
-
-    LINEITEM_PRODUCT = "zcrmsdk.src.com.zoho.crm.api.record.LineItemProduct"
-
     FILE_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.util.StreamWrapper"
 
     KEYS_TO_SKIP = ['Created_Time', 'Modified_Time', 'Created_By', 'Modified_By', 'Tag']
@@ -500,7 +484,7 @@ class Constants(object):
 
     RESOURCE_PATH_ERROR_MESSAGE = "Resource Path MUST NOT be None/empty."
 
-    SET_CONTENT_TYPE_HEADER = ["/crm/bulk/v2.1/read", "/crm/bulk/v2.1/write"]
+    SET_CONTENT_TYPE_HEADER = ["/crm/bulk/v2/read", "/crm/bulk/v2/write"]
 
     CONTENT_TYPE_HEADER = "Content-Type"
 
@@ -510,16 +494,6 @@ class Constants(object):
 
     FILE_ID = "file_id"
 
-    PHOTO_UPLOAD_ERROR_MESSAGE = "The given module is not supported in API."
-
-    INVALID_MODULE = "INVALID_MODULE"
-
-    MULTI_SELECT_LOOKUP = "multiselectlookup"
-
-    MULTI_USER_LOOKUP = "multiuserlookup"
-
-    TERRITORIES = "territories"
-
     GENERATED_TYPE = "generated_type"
 
     GENERATED_TYPE_CUSTOM = "custom"
@@ -528,10 +502,6 @@ class Constants(object):
 
     SDK_MODULE_METADATA = "SDK-MODULE-METADATA"
 
-    INVALID_MODULE_API_NAME_ERROR = "INVALID MODULE API NAME ERROR"
-
-    PROVIDE_VALID_MODULE_API_NAME = "PROVIDE VALID MODULE API NAME: "
-
     UPLOAD_PHOTO_UNSUPPORTED_ERROR = "UPLOAD PHOTO UNSUPPORTED MODULE"
 
     DELETE_FIELD_FILE_ERROR = "Exception in deleting Current User Fields file : "
@@ -616,8 +586,6 @@ class Constants(object):
 
     HEADER_NONE_ERROR = "NONE HEADER ERROR"
 
-    PRODUCT_NAME = "Product_Name"
-
     HEADER_INSTANCE_NONE_ERROR = "Header Instance MUST NOT be None"
 
     PARAM_INSTANCE_NONE_ERROR = "Param Instance MUST NOT be None"
