@@ -121,15 +121,11 @@ class JSONConverter(Converter):
                         required_in_update_keys.pop(key_name, None)
 
                     if isinstance(request_instance, FileDetails):
-                        if key_name.lower() == Constants.ATTACHMENT_ID.lower():
-                            request_json[key_name.lower()] = field_value
-
-                        elif key_name.lower() == Constants.FILE_ID.lower():
-                            request_json[key_name.lower()] = field_value
-
-                        else:
+                        if field_value is None or (isinstance(field_value,str) and field_value == "null"):
                             request_json[key_name.lower()] = None if field_value is None else field_value
-
+                        else:
+                            request_json[key_name.lower()] = field_value
+                        
                     else:
                         request_json[key_name] = self.set_data(member_detail, field_value)
 
@@ -675,8 +671,8 @@ class JSONConverter(Converter):
 
         return matches / total_points
 
-    def build_name(self, member_name):
-        name_split = str(member_name).split('_')
+    def build_name(self, key_name):
+        name_split = str(key_name).split('_')
         sdk_name = name_split[0].lower()
 
         if len(name_split) > 1:
