@@ -24,7 +24,7 @@ class VariableGroupsOperations(object):
 
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/settings/variable_groups'
+		api_path = api_path + '/crm/v2/settings/variable_groups'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
@@ -53,7 +53,7 @@ class VariableGroupsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/settings/variable_groups/'
+		api_path = api_path + '/crm/v2/settings/variable_groups/'
 		api_path = api_path + str(id)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
@@ -83,7 +83,7 @@ class VariableGroupsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/settings/variable_groups/'
+		api_path = api_path + '/crm/v2/settings/variable_groups/'
 		api_path = api_path + str(api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
